@@ -1,9 +1,9 @@
 use squawk_syntax::{
-    ast::{self, AstNode},
     Parse, SourceFile,
+    ast::{self, AstNode},
 };
 
-use crate::{text::trim_quotes, Linter, Rule, Violation};
+use crate::{Linter, Rule, Violation, text::trim_quotes};
 
 use super::constraint_missing_not_valid::tables_created_in_transaction;
 
