@@ -1,11 +1,11 @@
 use std::collections::HashMap;
 
 use squawk_syntax::{
-    ast::{self, AstNode},
     Parse, SourceFile,
+    ast::{self, AstNode},
 };
 
-use crate::{text::trim_quotes, Linter, Rule, Violation};
+use crate::{Linter, Rule, Violation, text::trim_quotes};
 
 #[derive(PartialEq)]
 enum Constraint {
